@@ -109,9 +109,13 @@ MLModel <- function(name = "MLModel", label = name, packages = character(),
 }
 
 
-MLModelFit <- function(object, Class, model, x, y) {
+.response_types <- c("binary", "BinomialVariate", "DiscreteVariate", "factor",
+                     "matrix", "NegBinomialVariate", "numeric", "ordered",
+                     "PoissonVariate", "Surv")
+
+
+MLModelFit <- function(object, Class, model, x) {
   model@x <- x
-  model@y <- y
 
   if (is(object, Class)) {
     object <- unMLModelFit(object)
