@@ -5,17 +5,14 @@
 #' @name fit
 #' @rdname fit-methods
 #'
-#' @param x defines a relationship between model predictor and response
-#'   variables.  May be a \code{\link{formula}}, design \code{\link{matrix}} of
-#'   predictors, \code{\link{ModelFrame}}, \code{\link{SelectedModelFrame}},
-#'   untrained \code{\link[recipes]{recipe}}, \code{\link{SelectedRecipe}}, or
-#'   \code{\link{TunedRecipe}} object.  Alternatively, a \link[=models]{model}
-#'   function or call may be given first followed by objects defining the
-#'   predictor and response relationship.
+#' @param x \link[=inputs]{input} specifying a relationship between model
+#'   predictor and response variables.  Alternatively, a \link[=models]{model}
+#'   function or call may be given first followed by the input specification.
 #' @param y response variable.
 #' @param data \link[=data.frame]{data frame} containing observed predictors and
 #'   outcomes.
-#' @param model \link[=models]{model} function, function name, or call.
+#' @param model \link[=models]{model} function, function name, or call; ignored
+#'   and can be omitted when fitting \link[=ModeledInput]{modeled inputs}.
 #' @param ... arguments passed to other methods.
 #'
 #' @return \code{MLModelFit} class object.
@@ -59,9 +56,8 @@ fit.matrix <- function(x, y, model, ...) {
 #' constructor.
 #'
 fit.ModelFrame <- function(x, model, ...) {
-  trained <- train(x, getMLObject(model, "MLModel"))
-  is_fully_trained <- !is(trained$x, "SelectedModelFrame")
-  (if (is_fully_trained) .fit else fit)(trained$model, trained$x)
+  model <- if (missing(model)) NullModel else getMLObject(model, "MLModel")
+  .fit(x, model)
 }
 
 
@@ -72,9 +68,8 @@ fit.ModelFrame <- function(x, model, ...) {
 #' with the \code{\link{role_case}} function.
 #'
 fit.recipe <- function(x, model, ...) {
-  trained <- train(x, getMLObject(model, "MLModel"))
-  is_fully_trained <- fully_trained(trained$x)
-  (if (is_fully_trained) .fit else fit)(trained$model, trained$x)
+  model <- if (missing(model)) NullModel else getMLObject(model, "MLModel")
+  .fit(x, model)
 }
 
 
@@ -88,25 +83,27 @@ fit.MLModel <- function(x, ...) {
 #' @rdname fit-methods
 #'
 fit.MLModelFunction <- function(x, ...) {
-  fit(..., model = x)
+  fit(x(), ...)
 }
 
 
-.fit <- function(model, x, ...) {
+.fit <- function(x, ...) {
   UseMethod(".fit")
 }
 
 
-.fit.MLModel <- function(model, x, ...) {
-  mf <- ModelFrame(x, na.rm = FALSE)
-  if (is.null(mf[["(weights)"]])) mf[["(weights)"]] <- 1
-
-  y <- response(mf)
-  if (!any(sapply(model@response_types, function(type) is_response(y, type)))) {
-    stop("invalid response type '", class(y)[1], "' for ", model@name)
+.fit.MLModel <- function(x, inputs, ...) {
+  mf <- ModelFrame(inputs, na.rm = FALSE)
+  if (is.null(model.weights(mf))) {
+    mf <- ModelFrame(mf, weights = 1, na.rm = FALSE)
   }
 
-  requireModelNamespaces(model@packages)
+  y <- response(mf)
+  if (!any(map_logi(function(type) is_response(y, type), x@response_types))) {
+    stop("invalid response type '", class(y)[1], "' for ", x@name)
+  }
+
+  requireModelNamespaces(x@packages)
 
   params_env <- list2env(list(
     formula = formula(mf),
@@ -114,14 +111,34 @@ fit.MLModelFunction <- function(x, ...) {
     weights = model.weights(mf),
     y = y,
     nobs = nrow(mf),
-    nvars = nvars(mf, model)
+    nvars = nvars(mf, x)
   ), parent = new.env(parent = asNamespace("MachineShop")))
   environment(params_env$formula) <- params_env
 
-  args <- c(mget(c("formula", "data", "weights"), params_env), model@params)
+  args <- c(mget(c("formula", "data", "weights"), params_env), x@params)
 
-  do.call(model@fit, args, envir = params_env) %>%
-    MLModelFit(paste0(model@name, "Fit"), model, x, y)
+  do.call(x@fit, args, envir = params_env) %>%
+    MLModelFit(paste0(x@name, "Fit"), model = x, x = inputs)
+}
+
+
+.fit.ModelFrame <- function(x, model, ...) {
+  .fit(model, x)
+}
+
+
+.fit.ModeledFrame <- function(x, ...) {
+  fit(as(x, "ModelFrame"), model = x@model)
+}
+
+
+.fit.ModeledRecipe <- function(x, ...) {
+  fit(as(x, "ModelRecipe"), model = x@model)
+}
+
+
+.fit.recipe <- function(x, model, ...) {
+  .fit(model, prep(ModelRecipe(x)))
 }
 
 
