@@ -64,17 +64,18 @@
 #'     "survival", "recipes")}].}
 #'   \item{\code{reset}}{character names of settings to reset to their default
 #'     values.}
-#'   \item{\code{stat.Curves}}{function or character string naming a function
+#'   \item{\code{stat.Curve}}{function or character string naming a function
 #'     to compute one \link{summary} statistic at each cutoff value of resampled
 #'     metrics in performance curves, or \code{NULL} for resample-specific
 #'     metrics [default: \code{"base::mean"}].}
 #'   \item{\code{stat.Resamples}}{function or character string naming a function
 #'     to compute one summary statistic to control the ordering of models in
 #'     \link[=plot]{plots} [default: \code{"base::mean"}].}
-#'   \item{\code{stat.Train}}{function or character string naming a function
+#'   \item{\code{stat.train}}{function or character string naming a function
 #'     to compute one summary statistic on resampled performance metrics for
-#'     \link[=SelectedModel]{model selection}, \link[=TunedModel]{model tuning},
-#'     and \link[=TunedRecipe]{recipe tuning} [default: \code{"base::mean"}].}
+#'     input \link[=SelectedInput]{selection} or \link[=TunedInput]{tuning} or
+#'     for model \link[=SelectedModel]{selection} or \link[=TunedModel]{tuning}
+#'     [default: \code{"base::mean"}].}
 #'   \item{\code{stats.PartialDependence}}{function, function name, or vector of
 #'     these with which to compute \link[=dependence]{partial dependence}
 #'     summary statistics [default: \code{c(Mean = "base::mean")}].}
@@ -123,7 +124,7 @@ settings <- function(...) {
   if (is.null(args_names)) args_names <- character(length(args))
   args_names_nzchar <- nzchar(args_names)
 
-  is_get_args <- !args_names_nzchar & sapply(args, is.character)
+  is_get_args <- !args_names_nzchar & vapply(args, is.character, logical(1))
   args_names[is_get_args] <- unlist(args[is_get_args])
 
   settings_pmatch <- pmatch(args_names, names(global_settings))
@@ -310,16 +311,12 @@ MachineShop_global <- as.environment(list(
     require = list(
       value = c("MachineShop", "survival", "recipes"),
       check = function(x) {
-        x <- c(setdiff(x, .global_defaults$require), .global_defaults$require)
-        found <- sapply(x, function(pkg) {
-          length(find.package(pkg, quiet = TRUE))
-        })
-        if (!all(found)) {
-          missing <- x[!found]
-          msg <- paste0(plural_suffix("given missing package", missing),
-                        ": ", toString(missing))
-          DomainError(x, msg)
-        } else x
+        x <- setdiff(x, .global_defaults$require)
+        available <- vapply(x, requireNamespace, logical(1), quietly = TRUE)
+        if (!all(available)) {
+          missing <- x[!available]
+          DomainError(x, label_items("given unavailable package", missing))
+        } else c(x, .global_defaults$require)
       }
     ),
 
@@ -340,7 +337,7 @@ MachineShop_global <- as.environment(list(
       }
     ),
 
-    stat.Curves = list(
+    stat.Curve = list(
       value = "base::mean",
       check = function(x) {
         if (!is.null(x) && is(check_stat(x), "error")) {
@@ -355,7 +352,7 @@ MachineShop_global <- as.environment(list(
       check = check_stat
     ),
 
-    stat.Train = list(
+    stat.train = list(
       value = "base::mean",
       check = check_stat
     ),
